import logging

logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO,  # avoid getting log from 3rd party module
                    format='RuleGeneration plugin %(levelname)s - %(message)s')

def train_and_deploy(doctor_task, 
                     train_dataset = None, 
                     session_name='riz_dinde', 
                     algorithm_name = None, 
                     recipe_model_name='riz_dinde', 
                     saved_model_info_dict={},
                     redeploy=False):

    logger.info("Training ....")
    training_session = doctor_task.start_train(session_name=session_name)
    doctor_task.wait_train_complete()
    
    algorithm_name = algorithm_name.upper() if isinstance(algorithm_name, str) else algorithm_name
    model_id_list = doctor_task.get_trained_models_ids(training_session['sessionId'], algorithm=algorithm_name)
    
    if not redeploy and train_dataset == None:
        raise ValueError("In deploy mode you need to specify a training datasett!")
    
    if redeploy and len(saved_model_info_dict) == 0:
        raise ValueError('In redeploy mode you need to choose a valid saved_model_info_dict!')
    
    if redeploy: 
        logger.info("Redeploying model {} to the flow ...".format(saved_model_info_dict['trainRecipeName']))
        impacts_Downstream = doctor_task.redeploy_to_flow(model_id = model_id_list[0], 
                                                          recipe_name = saved_model_info_dict['trainRecipeName'])
        return impacts_Downstream 
        
    else:
        logger.info("Deploying {} to the flow ...".format(recipe_model_name))
        saved_model_info_dict = doctor_task.deploy_to_flow(model_id = model_id_list[0], 
                                                           model_name = recipe_model_name, 
                                                           train_dataset=train_dataset)
        return saved_model_info_dict